//
//	Copyright  Nemetschek Vectorworks, Inc.
//	Use of this file is governed by the Nemetschek Vectorworks SDK License Agreement
//	http://developer.vectorworks.net/index.php?title=Vectorworks_SDK_License
//

#include "StdAfx.h"

#include "PluginResource.h"

#include "ExtObj.h"
#include "Obj_ShapePane.h"

using namespace TesterModule;

namespace TesterModule
{
	// --------------------------------------------------------------------------------------------------------
	static SParametricDef gParametricDef = {
		/*LocalizedName*/			{11000, 1},
		/*SubType*/					kParametricSubType_Point,
		/*ResetOnMove*/				false,
		/*ResetOnRotate*/			false,
		/*WallInsertOnEdge*/		false,
		/*WallInsertNoBreak*/		false,
		/*WallInsertHalfBreak*/		false,
		/*WallInsertHideCaps*/		false,
	};

	static SParametricParamChc	gArrChoices[] = {
		{ 128,	"Line",					{11002, 1} },
		{ 128,	"Arc",					{11002, 2} },
		{ 128,	"Bezier",				{11002, 3} },
		{ 128,	"None",					{11002, 4} },
		//------
		{ 129,	"Default Legend",		{11002, 5} },
		//------
		// TERMINATE
		{ NULL, NULL, {0,0} }
	};

	static SParametricParamDef gArrParameters[] = {
		{ "p1",			{11001, 1},		"False",	"False",	kFieldBoolean,		0 },
		{ "p2",			{11001, 2},		"False",	"False",	kFieldBoolean,		0 },
		{ "p3",			{11001, 3},		"",			"",			kFieldText,			0 },
		{ "p4",			{11001, 4},		"",			"",			kFieldText,			0 },
		{ "p5",			{11001, 5},		"2\"",		"2\"",		kFieldCoordDisp,	0 },
		{ "p6",			{11001, 6},		"Auto",		"Auto",		kFieldPopUp,		128 },
		{ "p7",			{11001, 7},		"Auto",		"Auto",		kFieldPopUp,		129 },
		{ "pAngle",		{11001, 8},		"15",		"15",		kFieldAngle,		0 },
		{ "pArea",		{11001, 9},		"1",		"1",		kFieldArea,			0 },
		{ "pVolume",	{11001, 10},	"2",		"2",		kFieldVolume,		0 },
		{ "pClass",		{11001, 11},	"None",		"Nodn",		kFieldClassesPopup,	0 },
		{ "pLayer",		{11001, 12},	"",			"",			kFieldLayersPopup,	0 },
		// TERMINATE
		{ NULL, {0,0}, NULL, NULL, EFieldStyle(0), 0 }
	};
}

// --------------------------------------------------------------------------------------------------------
// {CECBF2FC-875F-4046-8EA0-686FB206CA3B}
IMPLEMENT_VWExtension(
	/*Extension class*/	CExtObj,
	/*Event sink*/		CObj_EventSink,
	/*Universal name*/	"CExtObj_VWPluginWiz1",
	/*Version*/			1,
	/*UUID*/			0xcecbf2fc, 0x875f, 0x4046, 0x8e, 0xa0, 0x68, 0x6f, 0xb2, 0x6, 0xca, 0x3b );
// Test:
// SetSelect(CreateCustomObject('CExtObj_VWPluginWiz1',0,0,0));

// --------------------------------------------------------------------------------------------------------
// --------------------------------------------------------------------------------------------------------
CExtObj::CExtObj(CallBackPtr cbp)
	: VWExtensionParametric( cbp, gParametricDef, gArrParameters, gArrChoices )
{
}

CExtObj::~CExtObj()
{
}

void CExtObj::DefineSinks()
{
	this->DefineSink<CObj_ShapePane>( IID_ProviderShapePane );
}

// --------------------------------------------------------------------------------------------------------
// --------------------------------------------------------------------------------------------------------
CObj_EventSink::CObj_EventSink(IVWUnknown* parent)
	: VWParametric_EventSink( parent )
{
}

CObj_EventSink::~CObj_EventSink()
{
}

EObjectEvent CObj_EventSink::OnInitXProperties(CodeRefID objectID)
{
	// obtain the interfact for accessing the extended properties
	using namespace VectorWorks::Extension;
	VCOMPtr<IExtendedProps>	extProps( IID_ExtendedProps );


	return kObjectEventNoErr;
}


EObjectEvent CObj_EventSink::Recalculate()
{
	VWPoint3D	offset( -500, 0, 0 );

	VWPolygon3DObj	poly;
	poly.AddVertex( offset + VWPoint3D(50, 100, 0) );
	poly.AddVertex( offset + VWPoint3D(1000, 0, 0) );
	poly.AddVertex( offset + VWPoint3D(1000, 1000, 0) );
	poly.AddVertex( offset + VWPoint3D(100, 800, 0) );
	poly.SetClosed( true );


	return kObjectEventNoErr;
}
